==> haskell-megaparsec-9.6.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.6.1
visibility:           public
id:                   megaparsec-9.6.1-iLYYaEwT1u7mxYx9b63Ap
key:                  megaparsec-9.6.1-iLYYaEwT1u7mxYx9b63Ap
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  bc5d027f19d404ad04938cfd4492c379
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/megaparsec-9.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/megaparsec-9.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/megaparsec-9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.6.1-iLYYaEwT1u7mxYx9b63Ap
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4CWBjbNVYtn1DyQhk43ZQ9 containers-0.6.7
    deepseq-1.4.8.0 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    scientific-0.3.7.0-D2shAS6j7tCClWMfBXaB6J text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-9.6.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.6.1
visibility:           public
id:                   megaparsec-9.6.1-D3hnMTazjD69kPahnDEjhI
key:                  megaparsec-9.6.1-D3hnMTazjD69kPahnDEjhI
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  7d7485b5e0dc6221dd2021b004ab1b15
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/megaparsec-9.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/megaparsec-9.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/megaparsec-9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.6.1-D3hnMTazjD69kPahnDEjhI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-AtT9PetKXQ46vh6orGagap containers-0.6.7
    deepseq-1.4.8.0 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    scientific-0.3.7.0-Jh9tJE2sLMpFL2bSsP8DMA text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
